aboutsummaryrefslogtreecommitdiff
path: root/gdb
diff options
context:
space:
mode:
authorK. Richard Pixley <rich@cygnus>1993-08-13 21:47:01 +0000
committerK. Richard Pixley <rich@cygnus>1993-08-13 21:47:01 +0000
commit0e5f1b37f69f499d04861e7cd8d276c870289e71 (patch)
tree45faafa8dc58aefa122daf91e6e0e4eb2f049d93 /gdb
parentf2f848b8229ad6fda41a64ccd4ad562a747c8f65 (diff)
downloadgdb-0e5f1b37f69f499d04861e7cd8d276c870289e71.zip
gdb-0e5f1b37f69f499d04861e7cd8d276c870289e71.tar.gz
gdb-0e5f1b37f69f499d04861e7cd8d276c870289e71.tar.bz2
comment change
Diffstat (limited to 'gdb')
-rw-r--r--gdb/ChangeLog2
-rw-r--r--gdb/serial.h7
2 files changed, 6 insertions, 3 deletions
diff --git a/gdb/ChangeLog b/gdb/ChangeLog
index 3e165b0..dfdaab6 100644
--- a/gdb/ChangeLog
+++ b/gdb/ChangeLog
@@ -1,5 +1,7 @@
Fri Aug 13 14:37:05 1993 K. Richard Pixley (rich@sendai.cygnus.com)
+ * serial.h: comment change.
+
* config/m88k/tm-m88k.h: comment change to remove embedded
comment.
(SKIP_PROLOGUE): skip_prologue returns a value which is expected
diff --git a/gdb/serial.h b/gdb/serial.h
index a9dba27..808aad2 100644
--- a/gdb/serial.h
+++ b/gdb/serial.h
@@ -116,9 +116,10 @@ serial_t serial_fdopen PARAMS ((int fd));
((*((SERIAL_T)->ops->noflush_set_tty_state)) \
((SERIAL_T), (NEW_TTYSTATE), (OLD_TTYSTATE)))
-/* Read one char from the serial device with TIMEOUT seconds timeout.
- Returns char if ok, else one of the following codes. Note that all
- error codes are guaranteed to be < 0. */
+/* Read one char from the serial device with TIMEOUT seconds to wait
+ or -1 to wait forever. Use timeout of 0 to effect a poll. Returns
+ char if ok, else one of the following codes. Note that all error
+ codes are guaranteed to be < 0. */
#define SERIAL_ERROR -1 /* General error, see errno for details */
#define SERIAL_TIMEOUT -2